from django import VERSION as DJANGO_VERSION
from django.contrib.admin.sites import site as admin_site

__all__ = [
    'smart_text',
    'json',
    'admin_context',
    'patterns'
]

# Handle django.utils.encoding rename in 1.5

try:
    from django.utils.encoding import smart_text
except ImportError:
    from django.utils.encoding import smart_unicode as smart_text

# Old python, do we really need it?

try:
    import json
except ImportError:
    from django.utils import simplejson as json

# Django >= 1.8 needs has_permission in context

def admin_context(context, request):
    if DJANGO_VERSION >= (1, 8):
        return dict(admin_site.each_context(request), **context)

    return context

# django.conf.urls.patterns in django 1.9

if DJANGO_VERSION < (1, 9):
    from django.conf.urls import patterns
else:
    def patterns(prefix, *args):
        return list(args)



# coding: utf-8

from django import VERSION as DJANGO_VERSION
from django import template
from django.contrib.admin.templatetags.admin_static import static


register = template.Library()

# cycle

if DJANGO_VERSION < (1, 9):
    try:  # Import cycle from future for django 1.6+
        from django.templatetags.future import cycle
    except ImportError:
        pass
    else:
        register.tag(cycle)

# url

if DJANGO_VERSION < (1, 5):
    from django.templatetags.future import url
    register.tag(url)


# static

def static_jquery():
    if DJANGO_VERSION < (1, 9):
        return static("admin/js/jquery.min.js")

    return static("admin/js/vendor/jquery/jquery.min.js")

register.simple_tag(static_jquery)


def static_search_icon():
    if DJANGO_VERSION < (1, 9):
        return static("admin/img/icon_searchbox.png")

    return static("admin/img/search.svg")

register.simple_tag(static_search_icon)



from django.conf.urls import include, url
from django.contrib import admin

from filebrowser.sites import site

admin.autodiscover()

urlpatterns = [
    url(r'^admin/filebrowser/', include(site.urls)),
    url(r'^admin/', include(admin.site.urls)),
]
